==> honeybee-grasshopper-energy-1.2.0.tar.gz: honeybee-grasshopper-energy-1.2.0/honeybee_grasshopper_energy/src/HB Ground Construction Subset.py <==
# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2019, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Create a list of ground constructions that can be used to edit or create a
ConstructionSet object.
-

    Args:
        _ground_wall_: A construction object for underground walls (or text for
            the name of the construction within the library).
        _ground_roof_: A construction object for underground roofs (or text for
            the name of the construction within the library).
        _ground_floor_: A construction object for ground-contact floors (or text
            for the name of the construction within the library).
    
    Returns:
        ground_set: A list of ground constructions that can be used to edit
            or create a ConstructionSet object.
"""

ghenv.Component.Name = "HB Ground Construction Subset"
ghenv.Component.NickName = 'GroundSubset'
ghenv.Component.Message = '0.1.0'
ghenv.Component.Category = 'HB-Energy'
ghenv.Component.SubCategory = '0 :: Basic Properties'
ghenv.Component.AdditionalHelpFromDocStrings = "4"

try:  # import honeybee_energy dependencies
    from honeybee_energy.construction.opaque import OpaqueConstruction
    from honeybee_energy.lib.constructions import opaque_construction_by_name
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))


def opaque_constr(construction, input_name):
    """Get an OpaqueConstrucion from the library if it's a string."""
    if isinstance(construction, str):
        return opaque_construction_by_name(construction)
    else:
        assert isinstance(construction, OpaqueConstruction), \
            'Expected OpaqueConstruction for {}. Got {}'.format(
                input_name, type(construction))
    return construction


# go through each input construction
if _ground_wall_ is not None:
    _ground_wall_ = opaque_constr(_ground_wall_, '_ground_wall_')
if _ground_roof_ is not None:
    _ground_roof_ = opaque_constr(_ground_roof_, '_ground_roof_')
if _ground_floor_ is not None:
    _ground_floor_ = opaque_constr(_ground_floor_, '_ground_floor_')


# return the final list from the component
ground_set = [_ground_wall_, _ground_roof_, _ground_floor_]

==> honeybee-grasshopper-energy-1.20.3.tar.gz: honeybee-grasshopper-energy-1.20.3/honeybee_grasshopper_energy/src/HB Ground Construction Subset.py <==
# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2020, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Create a list of ground constructions that can be used to edit or create a
ConstructionSet object.
-

    Args:
        _ground_wall_: A construction object for underground walls (or text for
            the identifier of the construction within the library).
        _ground_roof_: A construction object for underground roofs (or text for
            the identifier of the construction within the library).
        _ground_floor_: A construction object for ground-contact floors (or text
            for the identifier of the construction within the library).
    
    Returns:
        ground_set: A list of ground constructions that can be used to edit
            or create a ConstructionSet object.
"""

ghenv.Component.Name = "HB Ground Construction Subset"
ghenv.Component.NickName = 'GroundSubset'
ghenv.Component.Message = '1.0.0'
ghenv.Component.Category = 'HB-Energy'
ghenv.Component.SubCategory = '0 :: Basic Properties'
ghenv.Component.AdditionalHelpFromDocStrings = "4"

try:  # import honeybee_energy dependencies
    from honeybee_energy.construction.opaque import OpaqueConstruction
    from honeybee_energy.lib.constructions import opaque_construction_by_identifier
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))


def opaque_constr(construction, input_name):
    """Get an OpaqueConstrucion from the library if it's a string."""
    if isinstance(construction, str):
        return opaque_construction_by_identifier(construction)
    else:
        assert isinstance(construction, OpaqueConstruction), \
            'Expected OpaqueConstruction for {}. Got {}'.format(
                input_name, type(construction))
    return construction


# go through each input construction
if _ground_wall_ is not None:
    _ground_wall_ = opaque_constr(_ground_wall_, '_ground_wall_')
if _ground_roof_ is not None:
    _ground_roof_ = opaque_constr(_ground_roof_, '_ground_roof_')
if _ground_floor_ is not None:
    _ground_floor_ = opaque_constr(_ground_floor_, '_ground_floor_')


# return the final list from the component
ground_set = [_ground_wall_, _ground_roof_, _ground_floor_]
